==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/metainfodialog.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "metainfodialog.h"
#include "mpdsong.h"

MetaInfoDialog::MetaInfoDialog(QWidget *parent, MPDSongList songs, bool radio) : QDialog(parent), m_pos(0) {
	setAttribute(Qt::WA_DeleteOnClose, true);
	if (songs.isEmpty()) {
		close();
		return;
	}
	m_songs = songs;
	setupUi(this);
	if (radio)
		hideFields();
	connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
	nextButton->setEnabled(songs.size() > 1);
	setSong();
	resize(minimumSizeHint());
	show();
}

void MetaInfoDialog::hideFields() {
	artistEdit->hide();
	albumEdit->hide();
	trackEdit->hide();
	genreEdit->hide();
	dateEdit->hide();
	composerEdit->hide();
	lengthEdit->hide();
	artistLabel->hide();
	albumLabel->hide();
	trackLabel->hide();
	genreLabel->hide();
	dateLabel->hide();
	composerLabel->hide();
	lengthLabel->hide();
}

void MetaInfoDialog::setSong() {
	progressLabel->setText(QString(tr("(%1 of %2)", "This is used in the context 'File number (%1 of %2)'.")).arg(m_pos+1).arg(m_songs.size()));
	MPDSong *song = m_songs.at(m_pos);
	trackEdit->setText(song->track());
	titleEdit->setText(song->title());
	artistEdit->setText(song->artist());
	albumEdit->setText(song->album());
	urlEdit->setText(song->url());
	lengthEdit->setText(song->time());
	genreEdit->setText(song->genre());
	dateEdit->setText(song->date());
	composerEdit->setText(song->composer());
}

void MetaInfoDialog::on_nextButton_clicked() {
	m_pos++;
	nextButton->setEnabled(m_pos < m_songs.size()-1);
	prevButton->setEnabled(true);
	setSong();
}

void MetaInfoDialog::on_prevButton_clicked() {
	m_pos--;
	prevButton->setEnabled(m_pos > 0);
	nextButton->setEnabled(true);
	setSong();
}

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/metainfodialog.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "metainfodialog.h"

MetaInfoDialog::MetaInfoDialog(QWidget *parent, const MPDSongList &songs, bool radio) : QDialog(parent), m_pos(0) {
	setAttribute(Qt::WA_DeleteOnClose, true);
	if (songs.isEmpty()) {
		close();
		return;
	}
	m_songs = songs;
	setupUi(this);
	if (radio)
		hideFields();
	connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
	nextButton->setEnabled(songs.size() > 1);
	setSong();
	resize(minimumSizeHint());
	show();
}

void MetaInfoDialog::hideFields() {
	artistEdit->hide();
	albumEdit->hide();
	trackEdit->hide();
	genreEdit->hide();
	dateEdit->hide();
	composerEdit->hide();
	lengthEdit->hide();
	artistLabel->hide();
	albumLabel->hide();
	trackLabel->hide();
	genreLabel->hide();
	dateLabel->hide();
	composerLabel->hide();
	lengthLabel->hide();
}

void MetaInfoDialog::setSong() {
	progressLabel->setText(QString(tr("(%1 of %2)", "This is used in the context 'File number (%1 of %2)'.")).arg(m_pos+1).arg(m_songs.size()));
	MPDSong song = m_songs.at(m_pos);
	trackEdit->setText(song.track());
	titleEdit->setText(song.title());
	artistEdit->setText(song.artist());
	albumEdit->setText(song.album());
	urlEdit->setText(song.url());
	lengthEdit->setText(song.time());
	genreEdit->setText(song.genre());
	dateEdit->setText(song.date());
	composerEdit->setText(song.composer());
}

void MetaInfoDialog::on_nextButton_clicked() {
	m_pos++;
	nextButton->setEnabled(m_pos < m_songs.size()-1);
	prevButton->setEnabled(true);
	setSong();
}

void MetaInfoDialog::on_prevButton_clicked() {
	m_pos--;
	prevButton->setEnabled(m_pos > 0);
	nextButton->setEnabled(true);
	setSong();
}
